%global momorel 2
%global boost_version 1.41.0

Name:           CGAL
Version:        3.6.1
Release:        %{momorel}m%{?dist}
Summary:        C++ library for computational geometry

Group:          System Environment/Libraries
License:        see "LICENSE"
URL:            http://www.cgal.org/
Source0:	https://gforge.inria.fr/frs/download.php/27224/CGAL-%{version}.tar.xz
NoSource: 	0

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Required devel packages.
BuildRequires: cmake
BuildRequires: boost-devel >= %{boost_version}
BuildRequires: qt-devel >= 4.6.3
BuildRequires: vtk-devel
BuildRequires: libQGLViewer-devel
BuildRequires: mpfr-devel
BuildRequires: gmp-devel
BuildRequires: blas-devel lapack-devel
BuildRequires: xorg-x11-proto-devel
BuildRequires: zlib-devel

%description
Libraries for CGAL applications.
CGAL is a collaborative effort of several sites in Europe and
Israel. The goal is to make the most important of the solutions and
methods developed in computational geometry available to users in
industry and academia in a C++ library. The goal is to provide easy
access to useful, reliable geometric algorithms.


%package devel
Group:          Development/Libraries
Summary:        Development files and tools for CGAL applications
Requires:       %{name} = %{version}-%{release}
Requires:       boost-devel >= %{boost_version}
Requires:	qt-devel >= 4.6.3
Requires:       blas-devel lapack-devel zlib-devel gmp-devel
Requires:       mpfr-devel
%description devel
The %{name}-devel package provides the headers files and tools you may need to 
develop applications using CGAL.

%package demos-source
Group:          Documentation
Summary:        Examples and demos of CGAL algorithms
Requires:       %{name}-devel = %{version}-%{release}
%description demos-source
The %{name}-demos-source package provides the sources of examples and demos of
CGAL algorithms.

%prep
%setup -q
chmod a-x demo/Circular_kernel_2/Circular_kernel_2.qrc

# remove the shipped copy of FindBoost.cmake (see bug #532431)
rm cmake/modules/FindBoost.cmake

%build

mkdir build
pushd build
%{cmake} \
      -DCGAL_INSTALL_LIB_DIR=%{_lib} \
      -DCMAKE_BUILD_TYPE=Release \
      -DCMAKE_SKIP_RPATH=TRUE \
      -DWITH_CGAL_Qt3=OFF \
      -DWITH_CGAL_Qt4=ON \
      -DWITH_examples=OFF \
      -DWITH_demos=OFF \
      ..
%make VERBOSE=1
popd

%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

pushd build
make install DESTDIR=%{buildroot}
rm -f %{buildroot}%{_bindir}/cgal_make_macosx_app
popd

# Install demos and examples
mkdir -p %{buildroot}%{_datadir}/CGAL
cp -a demo %{buildroot}%{_datadir}/CGAL/demo
cp -a examples %{buildroot}%{_datadir}/CGAL/examples

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE LICENSE.FREE_USE LICENSE.LGPL LICENSE.QPL CHANGES
%{_libdir}/libCGAL*.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/CGAL
%{_libdir}/libCGAL*.so
%{_libdir}/CGAL
%{_bindir}/*
%doc %{_mandir}/man1/*.1.*

%files demos-source
%defattr(-,root,root,-)
%dir %{_datadir}/CGAL
%{_datadir}/CGAL/demo
%{_datadir}/CGAL/examples

%changelog
* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (3.6.1-2m)
- full rebuild for mo7 release

* Thu Jul 15 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (3.6.1-1m)
- update to 3.6.1

* Mon Jun 28 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (3.6-2m)
- rebuild against qt-4.6.3-1m

* Sat Jun 26 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6-1m)
- update to 3.6

* Sat Dec 26 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.5.1-1m)
- update to 3.5.1 (bug fix release)

* Sun Nov 29 2009 NARITA Koichi <pulsar@momonga-linux.org>
- (3.5-4m)
- rebuild against boost-1.41.0

* Tue Nov 17 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.5-3m)
- import a fix from rawhide. see redhat's bugzilla #532431

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.5-2m)
- rebuild against gcc-4.4 and glibc-2.11

* Fri Oct 23 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.5-1m)
- update to 3.5 release version

* Sun Oct 11 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.5-0.2.2m)
- rebuild for boost-1.40.0

* Sat Oct 10 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.5-0.2.1m)
- fix Release

* Sat Aug 29 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.5-0.1m)
- update to CGAL-3.5-beta1

* Fri Jun 19 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.4-2m)
- fix typo 
- enable libQGLViewer support

* Sun Apr  5 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.4-1m)
- update 4.3

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.3.1-2m)
- rebuild against rpm-4.6

* Wed Oct  1 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.3.1-1m)
- inital import from fedora (CGAL-3_3_1-11_fc9)
